import unittest
from mongolian2ipa import mongolian2ipa


class MongoliaIPATest(unittest.TestCase):
    def test_a(self):
        result = mongolian2ipa('a')
        self.assertEqual(result, 'a')

    def test_aa(self):
        result = mongolian2ipa('аа')
        self.assertEqual(result, 'aː')

    def test_ai(self):
        result = mongolian2ipa('ай')
        self.assertEqual(result, 'æː')

    def test_a_with_i_ii(self):
        result = mongolian2ipa('ань')
        self.assertEqual(result[0], 'æ')


if __name__ == '__main__':
    unittest.main()



from mongolian2ipa.helpers import check_male_female_word, WordGender, vowels


# Characters functions
def a_convert(word: str, index: int) -> str:
    """
    а letter
    :param word:
    :param index:
    :return:
    """

    if not index == 0:
        if word[index - 1] in ['а', 'у']:
            return ''

    text = word[index:]

    is_ai = 'й' == text[1] if len(text) > 1 else False
    if is_ai:
        return 'æː'

    is_aa = 'а' == text[1] if len(text) > 1 else False

    # Check if the substring contains 'и', 'ь', or 'ий'
    is_i = 'и' == text[2] if len(text) > 2 else False
    is_soft = 'ь' == text[2] if len(text) > 2 else False

    if is_i or is_soft:
        if is_aa:
            return 'æː'
        else:
            return 'æ'

    if is_aa:
        return 'aː'

    return 'a'


def w_convert(word: str, index: int) -> str:
    """
     В letter
    :param word:
    :param index:
    :return:
    """

    if len(word) > index + 1:
        next_char = word[index + 1]

        if next_char == 'т' or next_char == 'ц' or next_char == 'ч':
            return 'ɸ'

    return 'w'


def k_convert(word: str, index: int) -> str:
    """
     Г letter
    :param word:
    :param index:
    :return:
    """

    gender = check_male_female_word(word)

    if gender == WordGender.MALE:
        if len(word) > index + 1:
            if word[index + 1] in vowels:
                return 'q'

    return 'k'


def o_convert(word: str, index: int) -> str:
    """
    О letter
    :param word:
    :param index:
    :return:
    """
    if not index == 0:
        if word[index - 1] == 'о':
            return ''

    text = word[index:]

    is_ai = 'й' == text[1] if len(text) > 1 else False
    if is_ai:
        return 'œː'

    is_oo = 'о' == text[1] if len(text) > 1 else False

    if is_oo:
        # Check if the substring contains 'и', 'ь', or 'ий'
        is_i = 'и' == text[3] if len(text) > 3 else False
        is_soft = 'ь' == text[3] if len(text) > 3 else False

        if is_i or is_soft:
            return 'œː'
        else:
            return 'ɔː'
    else:
        # Check if the substring contains 'и', 'ь', or 'ий'
        is_i = 'и' == text[2] if len(text) > 2 else False
        is_soft = 'ь' == text[2] if len(text) > 2 else False

        if is_i or is_soft:
            return 'œ'

    return 'ɔ'


def ou_convert(word: str, index: int) -> str:
    """
    Ө letter
    :param word:
    :param index:
    :return:
    """
    if not index == 0:
        if word[index - 1] == 'ө':
            return ''

    text = word[index:]

    is_ui = 'ө' == text[1] if len(text) > 1 else False
    if is_ui:
        return 'өː'

    return 'ө'


def u_convert(word: str, index: int) -> str:
    """
    У letter
    :param word:
    :param index:
    :return:
    """

    if not index == 0:
        if word[index - 1] == 'у':
            return ''

    text = word[index:]

    is_ui = 'й' == text[1] if len(text) > 1 else False
    if is_ui:
        return 'oi'

    is_ua = 'а' == text[1] if len(text) > 1 else False
    if is_ua:
        is_uai = 'й' == text[2] if len(text) > 2 else False

        if is_uai:
            return 'wæː'

        return 'waː'

    is_uu = 'у' == text[1] if len(text) > 1 else False

    if is_uu:
        # Check if the substring contains 'и', 'ь', or 'ий'
        is_i = 'и' == text[3] if len(text) > 3 else False
        is_soft = 'ь' == text[3] if len(text) > 3 else False

        if is_i or is_soft:
            return 'ʏː'
        else:
            return 'oː'
    else:
        # Check if the substring contains 'и', 'ь', or 'ий'
        is_i = 'и' == text[2] if len(text) > 2 else False
        is_soft = 'ь' == text[2] if len(text) > 2 else False

        if is_i or is_soft:
            return 'ʏ'

    return 'o'


def oo_convert(word: str, index: int) -> str:
    """
    Ү letter
    :param word:
    :param index:
    :return:
    """

    if not index == 0:
        if word[index - 1] == 'ү':
            return ''

    text = word[index:]

    is_ooi = 'й' == text[1] if len(text) > 1 else False
    if is_ooi:
        return 'ui'

    is_oooo = 'ү' == text[1] if len(text) > 1 else False

    if is_oooo:
        return 'uː'

    return 'u'


def h_convert(word: str, index: int) -> str:
    """
    Х letter
    :param word:
    :param index:
    :return:
    """
    if not index == 0:
        if word[index - 1] == 'л':
            return ''

    gender = check_male_female_word(word)

    if gender == WordGender.MALE:
        if len(word) > index + 1:
            if not word[index + 1] in ['т', 'ц', 'ч']:
                return 'ꭓ'

    return 'x'


def e_convert(word: str, index: int) -> str:
    """
    Э letter
    :param word:
    :param index:
    :return:
    """

    if not index == 0:
        if word[index - 1] == 'э':
            return ''

    text = word[index:]

    is_ei = 'й' == text[1] if len(text) > 1 else False
    if is_ei:
        return 'eː'

    is_ei = 'э' == text[1] if len(text) > 1 else False
    if is_ei:
        return 'eː'

    return 'e'


def yu_convert(word: str) -> str:
    gender = check_male_female_word(word)

    if gender == WordGender.MALE:
        return 'joː'
    else:
        return 'juː'


def ye_convert(word: str, index: int) -> str:
    """
    Е letter
    :param word:
    :param index:
    :return:
    """
    text = word[index]
    length = len(text)

    if not text.find('өө') == -1:
        return 'jө'

    if length > 2 and index + 1 < length and text[index + 1] == 'ө':
        return 'jөː'

    if length > 2 and index + 1 < length and text[index + 1] == 'э':
        return 'jeː'

    return 'je'


def ya_convert(word: str, index: int) -> str:
    """
    Я letter
    :param word:
    :param index:
    :return:
    """
    text = word[index:]
    length = len(text)

    if length > 2 and index + 2 < length and text[index + 2] == 'ь':
        return 'jæ'

    if length > 1:
        if index + 1 < length and text[index + 1] == 'й':
            return 'jæː'
        elif index + 1 < length and text[index + 1] == 'а':
            return 'jaː'

    return 'ja'


def yo_convert(word: str, index: int) -> str:
    """
    Ё letter
    :param word:
    :param index:
    :return:
    """
    text = word[index:]
    length = len(text)

    for c in text:
        if c in ['й', 'ь']:
            return 'jœ'

    if length > 2 and index + 1 < length and text[index + 1] == 'о':
        return 'jɔː'
    else:
        return 'jɔ'


def ii_convert(word: str, index: int) -> str:
    text = word[index:]
    length = len(text)

    if length > 2 and index + 1 < length and text[index + 1] == 'й':
        return 'iː'
    else:
        return 'i'


def l_convert(word: str, index: int) -> str:
    text = word[index:]
    length = len(text)

    if length > 2 and index + 1 < length and text[index + 1] == 'х':
        return 'ɬʰ'

    return 'ɬ'



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(name="mongolian2ipa", version="0.0.3", author="mnmonherdene",
                 author_email="mnmonherdene1234@gmail.com",
                 description="Mongolian text to International Phonetic Alphabet", long_description=long_description,
                 long_description_content_type="text/markdown",
                 url="https://github.com/mnmonherdene1234/mongolian-to-ipa", packages=setuptools.find_packages(),
                 classifiers=["Programming Language :: Python :: 3", "License :: OSI Approved :: MIT License",
                              "Operating System :: OS Independent", ], )



from enum import Enum

vowels = ['а', 'э', 'и', 'о', 'ө', 'ү', 'у']


class WordGender(Enum):
    MALE = 1
    FEMALE = 0


def check_male_female_word(word: str) -> WordGender:
    is_a = 'а' in word
    is_o = 'о' in word
    is_u = 'у' in word
    is_y = 'я' in word
    is_yu = 'ю' in word

    if is_a or is_o or is_u or is_y or is_yu:
        return WordGender.MALE

    is_e = 'э' in word
    is_oo = 'ө' in word
    is_uu = 'ү' in word

    if is_e or is_oo or is_uu:
        return WordGender.FEMALE

    return WordGender.FEMALE



from mongolian2ipa.char_convertor import a_convert, w_convert, k_convert, o_convert, ou_convert, u_convert, oo_convert, \
    h_convert, e_convert, yu_convert, ye_convert, ya_convert, ii_convert, l_convert
from mongolian2ipa.mongolia_ipa_dictionary import mongolian_to_ipa


def mongolian2ipa(text: str) -> str:
    text = text.lower()

    ipa_transcription = ''

    for i in range(len(text)):
        c = text[i]

        try:
            add_char = None

            if c == 'а':
                add_char = a_convert(text, i)

            if c == 'в':
                add_char = w_convert(text, i)

            if c == 'г':
                add_char = k_convert(text, i)

            if c == 'й':
                add_char = ''

            if c == 'о':
                add_char = o_convert(text, i)

            if c == 'ө':
                add_char = ou_convert(text, i)

            if c == 'у':
                add_char = u_convert(text, i)

            if c == 'ү':
                add_char = oo_convert(text, i)

            if c == 'х':
                add_char = h_convert(text, i)

            if c == 'э':
                add_char = e_convert(text, i)

            if c == 'ю':
                add_char = yu_convert(text)

            if c == 'е':
                add_char = ye_convert(text, i)

            if c == 'я':
                add_char = ya_convert(text, i)

            if c == 'и':
                add_char = ii_convert(text, i)

            if c == 'л':
                add_char = l_convert(text, i)

            # ignore characters:
            if c in ['й', 'ь', 'ъ']:
                add_char = ''

            if add_char is not None:
                ipa_transcription += add_char
            else:
                ipa_transcription += mongolian_to_ipa[c]
        except KeyError:
            ipa_transcription += c

    return ipa_transcription
